@@ -4,7 +4,7 @@
 from game_controls import game_controls
 
 while True:
-    cur_state = game_controls.button
+    cur_state = game_controls.button_state
     if cur_state["a"]:
         print("A btn!")
 
